use std::time::Duration;
use serialport::{DataBits, FlowControl, Parity, StopBits};
use crate::characteristics::LoupedeckDeviceCharacteristics;
use crate::device::LoupedeckDevice;

#[derive(Debug)]
pub struct AvailableLoupedeckDevice {
    pub(crate) port_name: String,
    pub(crate) characteristics: &'static LoupedeckDeviceCharacteristics,
}

impl AvailableLoupedeckDevice {
    pub fn port_name(&self) -> &str {
        &self.port_name
    }

    pub fn characteristics(&self) -> &'static LoupedeckDeviceCharacteristics {
        self.characteristics
    }

    pub fn open(&self) -> Result<LoupedeckDevice, serialport::Error> {
        Ok(LoupedeckDevice {
            port: Some(serialport::new(&self.port_name, 256000)
                .data_bits(DataBits::Eight)
                .stop_bits(StopBits::One)
                .parity(Parity::None)
                .flow_control(FlowControl::None)
                .timeout(Duration::from_secs(10))
                .open()?),
            characteristics: self.characteristics,
        })
    }
}